/*
 *
 * 07/24/1998 first public release, version 0.1.alpha
 *
 */


#include <qwidget.h>
#include <qevent.h>
#include <qpainter.h>

#include "mem.h"

#include "kconfig.h"

#include <qtooltip.h>
#include <stdio.h>

extern KConfig *config;

//------------------------------------------------------------
//  CONSTRUCTOR
//------------------------------------------------------------
MemMon::MemMon(QWidget *parent, const char *name, WFlags f)
    : QWidget ()
{
    //
    // get the configuration value for the update speed
    //
    timer_interval = 1000;     /* this is default (1 sec) */   
    tid = startTimer(timer_interval);

    //
    // initialize data values
    //
    updateValues();

    //
    // set up brushes for the painting job (black, blue, green)
    //

    blackBrush  = QBrush(QColor("black"), SolidPattern);
    cachedBrush = QBrush(QColor(   0, 165, 165), SolidPattern);
    bufferBrush = QBrush(QColor(   0, 255,   0), SolidPattern);
    usedBrush   = QBrush(QColor( 255,   0,   0), SolidPattern);
    swapBrush   = QBrush(QColor( 255, 255,   0), SolidPattern);
 
}

//------------------------------------------------------------
//  DESTRUCTOR
//------------------------------------------------------------
MemMon::~MemMon()
 {
    killTimer(tid);
 }

//------------------------------------------------------------
//  paintEvent
//------------------------------------------------------------
void MemMon::paintEvent(QPaintEvent * event)
{
    QPainter p;
    int temp, top;
    QRect area = event->rect();
    int height, width;
    p.begin(this);

    //
    // MEMORY
    //
    p.setWindow(0, 0, area.width(), area.height());
    p.fillRect(1, 1, area.width()-2, area.height()-2, blackBrush);
    width  = area.width()-3;
    height = area.height()-2;
    top = (int)(height*(double)freeMem / totalMem);
    p.fillRect(1, top+1, width/2+1, height-top, usedBrush);

    temp = (int)(height*(1-((double)bufferMem+cachedMem)/totalMem));
    p.fillRect(1, top+1, width/2+1, height-temp, bufferBrush);

    temp = (int)(height*(1- (double)cachedMem/totalMem));
    p.fillRect(1, top+1, width/2+1, height-temp, cachedBrush);

    //
    // SWAP
    //
    temp = (int)(height*((double)freeSwapMem/swapMem));
    p.fillRect(width-width/2+1, temp+1, width/2+1, height-temp, swapBrush);
    p.end();
}

//------------------------------------------------------------
//  timerEvent
//------------------------------------------------------------
void MemMon::timerEvent(QTimerEvent *)
{
    updateValues();

    repaint();
}

// Include system-specific code

#ifdef linux
#include "mem_linux.cpp"
#elif sgi
#include "mem_sgi.cpp"
#elif __FreeBSD__
#include "mem_fbsd.cpp"
#elif hpux
#include "mem_hpux.cpp"
#else

// Default for unsupported systems
void MemMon::updateValues() 
{
 //--- NOT AVAILABLE
 totalMem    = 0;
 usedMem     = 0;
 bufferMem   = 0;
 cachedMem   = 0;
 swapMem     = 0;
 freeSwapMem = 0;
 fprintf(stderr,"MemInfo not available on your OS \n");
 fprintf(stderr,"if you got infos on how to get info Email :laydier@usa.net\n");
}

#endif

